SuperchargeConfig class

Config for the SuperchargeView Full Documentation: https://map3.xyz/docs/supercharge

Constructors

SuperchargeConfig({required String anonKey, required String userId, SuperchargeConfigOptions? options})

Properties

anonKey → String
Generated via the console. Anon keys are public and can be safely used and exposed in a browser environment. They encode your organization ID and a role (anon). Anon key allows read access, but not write.
final
hashCode → int
The hash code for this object.
no setterinherited
options → SuperchargeConfigOptions?
Optional configuration for the supercharge SDK
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → String
A unique identifier for the active user. An email, uuid, or any other unique identifier is required.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited