SuperchargeConfigOptionsSelection class

Constructors

SuperchargeConfigOptionsSelection({String? address, String? amount, String? assetId, String? fiat = 'USD', String? networkCode, String? paymentMethod, List<int>? shortcutAmounts})

Properties

address → String?
The address of the ERC-20 token for the user to deposit. Must be used with networkCode or defaults to undefined.
final
amount → String?
The amount of crypto in minor units you require the user to deposit.
final
assetId → String?
If you know the Map3 assetId (e.g fe2bf2f8-3ddc-4ccc-8f34-8fdd9be03884 USDC on Polygon) you can pass in the assetId and skip directly to payment method selection. If you have more questions about the Map3 assetId please review Metadata Documentation.
final
fiat → String?
Fiat currency of your user's preference. Default value is USD.
final
hashCode → int
The hash code for this object.
no setterinherited
networkCode → String?
If the user wants to deposit the native token (e.g Ether on Ethereum) you can pass in a networkCode to skip asset and network selection and jump directly to payment method selection.
final
paymentMethod → String?
Pass in 'binance-pay' or 'show-address' payment methods to auto-select that method for your user. If not set, then the onAddressRequested callback is required.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortcutAmounts → List<int>?
You can configure the shortcut amounts users can select from on the deposit screen.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited