SuperchargeConfigOptionsStyle class

Constructors

SuperchargeConfigOptionsStyle({String? appName, Map<String, String>? colors, String? locale = 'en', String? theme = 'light'})

Properties

appName → String?
Document title: shown when connecting to user's wallet via metamask or walletconnect
final
colors → Map<String, String>?
Change the primary and accent colors, e.g. {primary: '#ffffff', accent: '#000000'}
final
hashCode → int
The hash code for this object.
no setterinherited
locale → String?
Locale to define in which language the supercharge SDK should appear. Defaults to 'en'.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
theme → String?
'light' or 'dark' mode is supported. 'light' by default.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited